setUnitFactory method
Sets the factory function used to create the initial unit.
This method must be called before buildUnit is invoked.
Implementation
void setUnitFactory(UnitFactory<Unit, Args> unitFactory) =>
_unitFactory = unitFactory;
Sets the factory function used to create the initial unit.
This method must be called before buildUnit is invoked.
void setUnitFactory(UnitFactory<Unit, Args> unitFactory) =>
_unitFactory = unitFactory;